fn on_handshake_finalize(context: &mut Context) -> Status
Finalizes the handshake by sending the list of files to the receiver and starting the file transfer task.
context
A Status indicating the success or failure of the handshake finalization.
Status