Function caesar_core::sender::client::on_message
source · fn on_message(
context: &mut Context,
message: Message,
relay: String,
transfer_name: String,
is_local: bool
) -> StatusExpand description
Handles the incoming message from the WebSocket.
Arguments
context- The mutable context holding the sender and shared key.message- The incoming WebSocket message.relay- The URL of the relay.transfer_name- The name of the transfer.is_local- Whether the transfer is local or not.
Returns
A Status indicating the success or failure of handling the message.